@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from typing import get_args, Optional, TYPE_CHECKING
+from typing import Optional, TYPE_CHECKING
 
 from compass.core._scrapers.member import PeopleScraper
+from compass.core._scrapers.member import STATUSES
 from compass.core.schemas.member import TYPES_ROLE_STATUS
 
 if TYPE_CHECKING:
@@ -15,19 +16,18 @@ if TYPE_CHECKING:
 # MAIN CLASS - object/properties focused, with abstractions of actual calls
 # UTILITY CLASS - get_member_data, get_roles_from_members, etc
 
-STATUSES = set(get_args(TYPES_ROLE_STATUS))
-
 
 class People:
     def __init__(self, session: Logon):
         """Constructor for People."""
-        self._scraper = PeopleScraper(session.s, session.cn, session.mrn, session.jk)
+        self._scraper = PeopleScraper(session._session)
+        self.membership_number = session.membership_number
 
-    def personal(self, membership_num: int) -> schema.MemberDetails:
+    def personal(self, membership_number: int) -> schema.MemberDetails:
         """Gets personal tab data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             A MemberDetails object containing all data.
@@ -40,12 +40,12 @@ class People:
                 data for the requested member.
 
         """
-        return self._scraper.get_personal_tab(membership_num)
+        return self._scraper.get_personal_tab(membership_number)
 
     # See getRole in PGS\Needle
     def roles(
         self,
-        membership_num: int,
+        membership_number: int,
         keep_non_volunteer_roles: bool = False,
         only_active: bool = False,
         statuses: Optional[Iterable[TYPES_ROLE_STATUS]] = None,
@@ -55,7 +55,7 @@ class People:
         Sanitises the data to a common format, and removes Occasional Helper, Network, and PVG roles by default.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
             keep_non_volunteer_roles: Keep Helper (OH/PVG) & Network roles?
             only_active: Keep only active (Full, Provisional, Pre-Provisional) roles?
             statuses: Explicit set of role statuses to keep
@@ -73,12 +73,12 @@ class People:
         """
         if only_active:
             # TODO look into `ROLE_HIDEME` in the roles rows - does this apply to (Pre-)Prov or just Closed/Cancelled?
-            unique_statuses = STATUSES - {"Closed", "Cancelled"}
+            unique_statuses: Optional[set[str]] = STATUSES - {"Closed", "Cancelled"}
         elif statuses is None:
             unique_statuses = None
         else:
             unique_statuses = set(statuses)
-        return self._scraper.get_roles_tab(membership_num, keep_non_volunteer_roles, unique_statuses)
+        return self._scraper.get_roles_tab(membership_number, keep_non_volunteer_roles, unique_statuses)
 
     def role_detail(self, role_number: int) -> schema.MemberRolePopup:
         """Get detailed information for specified role.
@@ -102,11 +102,11 @@ class People:
         """
         return self._scraper.get_roles_detail(role_number)
 
-    def permits(self, membership_num: int) -> list[schema.MemberPermit]:
+    def permits(self, membership_number: int) -> list[schema.MemberPermit]:
         """Gets permits tab data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             requests.exceptions.RequestException:
@@ -114,13 +114,13 @@ class People:
             A MemberPermitsList object containing all data.
 
         """
-        return self._scraper.get_permits_tab(membership_num)
+        return self._scraper.get_permits_tab(membership_number)
 
-    def training(self, membership_num: int) -> schema.MemberTrainingTab:
+    def training(self, membership_number: int) -> schema.MemberTrainingTab:
         """Gets training tab data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             requests.exceptions.RequestException:
@@ -128,13 +128,13 @@ class People:
             A MemberTrainingTab object containing all data.
 
         """
-        return self._scraper.get_training_tab(membership_num, ongoing_only=False)
+        return self._scraper.get_training_tab(membership_number, ongoing_only=False)
 
-    def ongoing_learning(self, membership_num: int) -> schema.MemberMandatoryTraining:
+    def ongoing_learning(self, membership_number: int) -> schema.MemberMandatoryTraining:
         """Gets ongoing learning data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             requests.exceptions.RequestException:
@@ -142,13 +142,13 @@ class People:
             A MemberMOGLList object containing all data.
 
         """
-        return self._scraper.get_training_tab(membership_num, ongoing_only=True)
+        return self._scraper.get_training_tab(membership_number, ongoing_only=True)
 
-    def awards(self, membership_num: int) -> list[schema.MemberAward]:
+    def awards(self, membership_number: int) -> list[schema.MemberAward]:
         """Gets awards tab data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             A MemberAward object containing all data.
@@ -161,13 +161,13 @@ class People:
                 data for the requested member.
 
         """
-        return self._scraper.get_awards_tab(membership_num)
+        return self._scraper.get_awards_tab(membership_number)
 
-    def disclosures(self, membership_num: int) -> list[schema.MemberDisclosure]:
+    def disclosures(self, membership_number: int) -> list[schema.MemberDisclosure]:
         """Gets disclosures tab data for a given member.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             A list of MemberDisclosure objects containing all data.
@@ -180,15 +180,15 @@ class People:
                 disclosure data for the requested member.
 
         """
-        return self._scraper.get_disclosures_tab(membership_num)
+        return self._scraper.get_disclosures_tab(membership_number)
 
-    def latest_disclosure(self, membership_num: int) -> Optional[schema.MemberDisclosure]:
+    def latest_disclosure(self, membership_number: int) -> Optional[schema.MemberDisclosure]:
         """Gets latest disclosure for a given member.
 
         Latest is defined as the expiry date that is furthest away.
 
         Args:
-            membership_num: Membership Number to use
+            membership_number: Membership Number to use
 
         Returns:
             A MemberDisclosure objects containing disclosure data.
@@ -201,7 +201,7 @@ class People:
                 disclosure data for the requested member.
 
         """
-        disclosures = self.disclosures(membership_num)
+        disclosures = self.disclosures(membership_number)
         date_map = {disc.expiry_date: disc for disc in disclosures if disc.expiry_date}
         if not date_map:
             return None
