@@ -41,9 +41,9 @@ TYPES_RELIGION = Union[  # type: ignore[misc]
         "No religion",
         "Prefer not to say",
     ],
-    pydantic.constr(regex=r"^Christian.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Any other religion.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^No religion.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Christian.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Any other religion.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^No religion.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
 ]
 TYPES_OCCUPATION = Union[  # type: ignore[misc]
     Literal[
@@ -55,13 +55,13 @@ TYPES_OCCUPATION = Union[  # type: ignore[misc]
         "Looking after home of family",
         "Other",
     ],
-    pydantic.constr(regex=r"^Employed.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Unemployed.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Retired.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Student.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Long term sick or disabled.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Looking after home of family.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
-    pydantic.constr(regex=r"^Other.*"),  # NoQA F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Employed.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Unemployed.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Retired.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Student.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Long term sick or disabled.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Looking after home of family.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
+    pydantic.constr(regex=r"^Other.*"),  # NoQA: F722 (https://stackoverflow.com/a/64917499)
 ]
 TYPES_ROLE_CLASS = Literal[
     "Administrator",
@@ -237,6 +237,15 @@ class MemberRoleBase(pydantic.BaseModel):
     review_date: Optional[datetime.date] = None
 
 
+class MemberDetailsAddress(pydantic.BaseModel):
+    unparsed_address: Optional[str] = None  # this is the unmodified address string
+    country: Optional[str] = None
+    postcode: Optional[str] = None
+    county: Optional[str] = None
+    town: Optional[str] = None
+    street: Optional[str] = None
+
+
 # Personal Details Tab
 class MemberDetails(MemberBase):
     # Name
@@ -257,30 +266,29 @@ class MemberDetails(MemberBase):
     # Contact Details
     main_phone: Optional[str] = None
     main_email: Optional[pydantic.EmailStr] = None
-    address: Optional[str] = None  # this is the unmodified address string
-    country: Optional[str] = None
-    postcode: Optional[str] = None
-    county: Optional[str] = None
-    town: Optional[str] = None
-    street: Optional[str] = None
+    address: MemberDetailsAddress = MemberDetailsAddress()
 
     # Additional / miscellaneous details
-    # TODO - potential disabilities, qualifications, hobbies sections
+    disabilities: Optional[dict[str, str]] = None  # TODO keyed models
+    qualifications: Optional[dict[str, str]] = None
+    hobbies: Optional[dict[str, str]] = None
 
+    # pylint doesn't support custom decorators. https://github.com/PyCQA/pylint/issues/1694
+    # pylint: disable=no-self-use
     @pydantic.validator("main_phone")
-    def check_phone_number(cls, v: Optional[str], values: dict[str, Optional[Union[str, datetime.date]]]) -> Optional[str]:
+    def check_phone_number(cls, v: Optional[str], values: dict[str, object]) -> Optional[str]:
         if v is None or not v or v == "0" or len(v) < 2:
             return None
 
         try:
             n = phonenumbers.parse(v, "GB")
         except phonenumbers.NumberParseException as err:
-            cn = values["membership_number"]
-            raise ValueError(f"Member No {cn}: phone number {v} is not valid!") from err
+            membership_number = values["membership_number"]
+            raise ValueError(f"Member No {membership_number}: phone number {v} is not valid!") from err
 
         if not phonenumbers.is_valid_number(n):
-            cn = values["membership_number"]
-            warnings.warn(f"Member No {cn}: phone number {v} is not valid!", RuntimeWarning)
+            membership_number = values["membership_number"]
+            warnings.warn(f"Member No {membership_number}: phone number {v} is not valid!", RuntimeWarning)
 
         fmt = phonenumbers.PhoneNumberFormat.NATIONAL if n.country_code == 44 else phonenumbers.PhoneNumberFormat.INTERNATIONAL
         return str(phonenumbers.format_number(n, fmt))
@@ -389,8 +397,8 @@ class MemberTrainingRole(MemberRoleBase):
 class MemberTrainingPLP(pydantic.BaseModel):
     pk: int
     module_id: int
-    code: str  # TODO literal
-    name: str  # TODO literal
+    code: str  # We could do literals for module name/code but this would be ~150 values
+    name: str
 
     # Learning details
     learning_required: Optional[bool]
